@@ -20,49 +20,57 @@
 #include <kfilemetainfo.h>
 #include <kfileitem.h>
 #include <kapplication.h>
+#include <kdeversion.h>
 #include <qtextcodec.h>
 
 #define STRIGI_IMPORT_API //todo: could also define this in cmake...
 #include <jstreamsconfig.h>
-#include <strigi_plugins.h>
+#include <analyzerplugin.h>
+#include <streamthroughanalyzer.h>
+#include <indexable.h>
 
-class KFileAnalyzer : public jstreams::StreamThroughAnalyzer {
+using namespace jstreams;
+using namespace std;
+
+class KFileAnalyzer : public StreamThroughAnalyzer {
 private:
     static KApplication app;
-    jstreams::Indexable* idx;
+    Indexable* idx;
 public:
     KFileAnalyzer() {
         // translate filenames from UTF-8
         QTextCodec::setCodecForCStrings(QTextCodec::codecForName("utf8"));
     }
     ~KFileAnalyzer() {}
-     void setIndexable(jstreams::Indexable*i) {
+     void setIndexable(Indexable*i) {
         idx = i;
     }
-    jstreams::InputStream *connectInputStream(jstreams::InputStream *in) {
+    InputStream *connectInputStream(InputStream *in) {
         if ((int)idx->getDepth() != 0) {
 //             std::cout << "Not depth=0, returning\n";
             return in;
         }
 
         // ok, determing path:
-        if (idx->getName().length() == 0) {
+        if (idx->getPath().length() == 0) {
 //             std::cout << "No file name; returning\n";
             return in;
         }
 
         // don't try to do image/xpm files, as KDE < 3.5.6 crashes on those
-        std::string s = idx->getName();
-        int n = s.length();
-        if (n < 3) {
-        } else if (s.substr(n-3,3)=="xpm") {
-            return in;
-        } else if (s.substr(n-3,3)=="XPM") {
-            return in;
-        }
- 
+	if (KDE_IS_VERSION(3,5,6)) {
+            std::string s = idx->getFileName();
+            int n = s.length();
+            if (n < 3) {
+            } else if (s.substr(n-3,3)=="xpm") {
+                return in;
+            } else if (s.substr(n-3,3)=="XPM") {
+                return in;
+            }
+	}
+
         // Then create a new KFileMetaInfo object
-        KFileMetaInfo info( KURL::fromPathOrURL( idx->getName().c_str() ),
+        KFileMetaInfo info( KURL::fromPathOrURL( idx->getPath().c_str() ),
             QString::null,
             KFileMetaInfo::TechnicalInfo|KFileMetaInfo::ContentInfo);
         // See: http://developer.kde.org/documentation/library/cvs-api/kdelibs-apidocs/kio/kio/html/classKFileMetaInfo.html
@@ -91,12 +99,27 @@ public:
     bool isReadyWithStream() { return true; }
 };
 
-char* fileanalyzerargv[] = {"strigita_kfile"};
-int fileanalyzerargc = 1;
-KApplication KFileAnalyzer::app(fileanalyzerargc, fileanalyzerargv,
-    "kio_strigi", false, false);
+class KFileThroughAnalyzerFactory
+    : public StreamThroughAnalyzerFactory {
+private:
+    const char* getName() const {
+        return "KFileThroughAnalyzer";
+    }
+    StreamThroughAnalyzer* newInstance() const {
+        return new KFileAnalyzer();
+    }
+};
+
+class Factory : public AnalyzerFactoryFactory {
+public:
+    list<StreamThroughAnalyzerFactory*>
+    getStreamThroughAnalyzerFactories() const {
+        list<StreamThroughAnalyzerFactory*> af;
+        af.push_back(new KFileThroughAnalyzerFactory());
+        return af;
+    }
+};
+
+STRIGI_ANALYZER_FACTORY(Factory)
 
-STRIGI_THROUGH_PLUGINS_START
-STRIGI_THROUGH_PLUGINS_REGISTER(KFileAnalyzer)
-STRIGI_THROUGH_PLUGINS_END
 
